@@ -1,7 +1,9 @@
-snapshotRenvDependencies <- function(bundleDir,
-                                     extraPackages = character(),
-                                     quiet = FALSE,
-                                     verbose = FALSE) {
+snapshotRenvDependencies <- function(
+  bundleDir,
+  extraPackages = character(),
+  quiet = FALSE,
+  verbose = FALSE
+) {
   recordExtraDependencies(bundleDir, extraPackages)
 
   old <- options(
@@ -25,7 +27,8 @@ snapshotRenvDependencies <- function(bundleDir,
     bundleDir,
     root = bundleDir,
     quiet = if (quiet) TRUE else NULL,
-    progress = FALSE)
+    progress = FALSE
+  )
   renv::snapshot(bundleDir, packages = deps$Package, prompt = FALSE)
   defer(removeRenv(bundleDir))
 
@@ -82,15 +85,21 @@ standardizeRenvPackages <- function(packages, repos, biocPackages = NULL) {
   rbind_fill(out)
 }
 
-standardizeRenvPackage <- function(pkg,
-                                   availablePackages,
-                                   biocPackages = NULL,
-                                   repos = character(),
-                                   bioc) {
+standardizeRenvPackage <- function(
+  pkg,
+  availablePackages,
+  biocPackages = NULL,
+  repos = character(),
+  bioc
+) {
   # Convert renv source to manifest source/repository
   # https://github.com/rstudio/renv/blob/0.17.2/R/snapshot.R#L730-L773
 
-  if (is.null(pkg$Repository) && !is.null(pkg$RemoteRepos) && grepl("bioconductor.org", pkg$RemoteRepos)) {
+  if (
+    is.null(pkg$Repository) &&
+      !is.null(pkg$RemoteRepos) &&
+      grepl("bioconductor.org", pkg$RemoteRepos)
+  ) {
     # Work around bug where renv fails to detect BioC package installed by pak
     # https://github.com/rstudio/renv/issues/1202
     pkg$Source <- "Bioconductor"
@@ -108,8 +117,15 @@ standardizeRenvPackage <- function(pkg,
     } else {
       # $Repository comes from DESCRIPTION and is set by repo, so can be
       # anything. So we must look up from the package name
+      originalRepository <- pkg$Repository
       pkg$Repository <- findRepoUrl(pkg$Package, availablePackages)
       pkg$Source <- findRepoName(pkg$Repository, repos)
+      if (is.na(pkg$Source)) {
+        # Archived packages are not publicized by available.packages(). Use
+        # the renv.lock repository as source, expecting that the package is
+        # available through one of the repository URLs.
+        pkg$Source <- originalRepository
+      }
     }
   } else if (pkg$Source == "Bioconductor") {
     pkg$Repository <- findRepoUrl(pkg$Package, availablePackages)
