@@ -1,4 +1,3 @@
-
 # This is the user-interface definition of a Shiny web application.
 # You can find out more about building applications with Shiny here:
 #
@@ -8,21 +7,16 @@
 library(shiny)
 
 shinyUI(fluidPage(
-
   # Application title
   titlePanel("Old Faithful Geyser Data"),
 
   # Some image
-  img(src="/images/icon.png"),
+  img(src = "/images/icon.png"),
 
   # Sidebar with a slider input for number of bins
   sidebarLayout(
     sidebarPanel(
-      sliderInput("bins",
-                  "Number of bins:",
-                  min = 1,
-                  max = 50,
-                  value = 30)
+      sliderInput("bins", "Number of bins:", min = 1, max = 50, value = 30)
     ),
 
     # Show a plot of the generated distribution
